You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by da...@apache.org on 2023/12/07 18:06:21 UTC

(camel) 02/03: Regen

This is an automated email from the ASF dual-hosted git repository.

davsclaus pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/camel.git

commit 000d73e8682d12c7262594df595864ffe605892b
Author: Claus Ibsen <cl...@gmail.com>
AuthorDate: Thu Dec 7 18:52:18 2023 +0100

    Regen
---
 .../component/ComponentsBuilderFactory.java        |   14 +
 .../component/dsl/HdfsComponentBuilderFactory.java |    1 +
 ... KubernetesCronjobComponentBuilderFactory.java} |   74 +-
 .../dsl/KubernetesJobComponentBuilderFactory.java  |   30 +-
 .../src/generated/resources/metadata.json          |   26 +-
 .../builder/endpoint/EndpointBuilderFactory.java   |    1 +
 .../camel/builder/endpoint/EndpointBuilders.java   |    1 +
 .../builder/endpoint/StaticEndpointBuilders.java   |   45 +
 .../endpoint/dsl/HdfsEndpointBuilderFactory.java   |    3 +
 .../KubernetesCronJobEndpointBuilderFactory.java   |  579 ++++++++++
 .../dsl/KubernetesJobEndpointBuilderFactory.java   | 1124 ++------------------
 .../endpoint/dsl/LogEndpointBuilderFactory.java    |   62 ++
 12 files changed, 826 insertions(+), 1134 deletions(-)

diff --git a/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/ComponentsBuilderFactory.java b/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/ComponentsBuilderFactory.java
index ee85d87905b..f419b69c24a 100644
--- a/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/ComponentsBuilderFactory.java
+++ b/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/ComponentsBuilderFactory.java
@@ -1851,6 +1851,7 @@ public interface ComponentsBuilderFactory {
      * 
      * @return the dsl builder
      */
+    @Deprecated
     static org.apache.camel.builder.component.dsl.HdfsComponentBuilderFactory.HdfsComponentBuilder hdfs() {
         return org.apache.camel.builder.component.dsl.HdfsComponentBuilderFactory.hdfs();
     }
@@ -2480,6 +2481,19 @@ public interface ComponentsBuilderFactory {
     static org.apache.camel.builder.component.dsl.KubernetesConfigMapsComponentBuilderFactory.KubernetesConfigMapsComponentBuilder kubernetesConfigMaps() {
         return org.apache.camel.builder.component.dsl.KubernetesConfigMapsComponentBuilderFactory.kubernetesConfigMaps();
     }
+    /**
+     * Kubernetes Cronjob (camel-kubernetes)
+     * Perform operations on Kubernetes CronJob.
+     * 
+     * Category: container,cloud
+     * Since: 4.3
+     * Maven coordinates: org.apache.camel:camel-kubernetes
+     * 
+     * @return the dsl builder
+     */
+    static org.apache.camel.builder.component.dsl.KubernetesCronjobComponentBuilderFactory.KubernetesCronjobComponentBuilder kubernetesCronjob() {
+        return org.apache.camel.builder.component.dsl.KubernetesCronjobComponentBuilderFactory.kubernetesCronjob();
+    }
     /**
      * Kubernetes Custom Resources (camel-kubernetes)
      * Perform operations on Kubernetes Custom Resources and get notified on
diff --git a/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/HdfsComponentBuilderFactory.java b/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/HdfsComponentBuilderFactory.java
index fe42cbb3267..9de09c3f162 100644
--- a/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/HdfsComponentBuilderFactory.java
+++ b/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/HdfsComponentBuilderFactory.java
@@ -40,6 +40,7 @@ public interface HdfsComponentBuilderFactory {
      * 
      * @return the dsl builder
      */
+    @Deprecated
     static HdfsComponentBuilder hdfs() {
         return new HdfsComponentBuilderImpl();
     }
diff --git a/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/KubernetesJobComponentBuilderFactory.java b/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/KubernetesJobComponentBuilderFactory.java
index d9841d873d9..495a8ca9bb0 100644
--- a/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/KubernetesJobComponentBuilderFactory.java
+++ b/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/KubernetesJobComponentBuilderFactory.java
@@ -56,7 +56,7 @@ public interface KubernetesJobComponentBuilderFactory {
          * The option is a:
          * &lt;code&gt;io.fabric8.kubernetes.client.KubernetesClient&lt;/code&gt; type.
          * 
-         * Group: common
+         * Group: producer
          * 
          * @param kubernetesClient the value to set
          * @return the dsl builder
@@ -66,33 +66,6 @@ public interface KubernetesJobComponentBuilderFactory {
             doSetProperty("kubernetesClient", kubernetesClient);
             return this;
         }
-        /**
-         * Allows for bridging the consumer to the Camel routing Error Handler,
-         * which mean any exceptions (if possible) occurred while the Camel
-         * consumer is trying to pickup incoming messages, or the likes, will
-         * now be processed as a message and handled by the routing Error
-         * Handler. Important: This is only possible if the 3rd party component
-         * allows Camel to be alerted if an exception was thrown. Some
-         * components handle this internally only, and therefore
-         * bridgeErrorHandler is not possible. In other situations we may
-         * improve the Camel component to hook into the 3rd party component and
-         * make this possible for future releases. By default the consumer will
-         * use the org.apache.camel.spi.ExceptionHandler to deal with
-         * exceptions, that will be logged at WARN or ERROR level and ignored.
-         * 
-         * The option is a: &lt;code&gt;boolean&lt;/code&gt; type.
-         * 
-         * Default: false
-         * Group: consumer
-         * 
-         * @param bridgeErrorHandler the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobComponentBuilder bridgeErrorHandler(
-                boolean bridgeErrorHandler) {
-            doSetProperty("bridgeErrorHandler", bridgeErrorHandler);
-            return this;
-        }
         /**
          * Whether the producer should be started lazy (on the first message).
          * By starting lazy you can use this to allow CamelContext and routes to
@@ -156,7 +129,6 @@ public interface KubernetesJobComponentBuilderFactory {
                 Object value) {
             switch (name) {
             case "kubernetesClient": ((KubernetesJobComponent) component).setKubernetesClient((io.fabric8.kubernetes.client.KubernetesClient) value); return true;
-            case "bridgeErrorHandler": ((KubernetesJobComponent) component).setBridgeErrorHandler((boolean) value); return true;
             case "lazyStartProducer": ((KubernetesJobComponent) component).setLazyStartProducer((boolean) value); return true;
             case "autowiredEnabled": ((KubernetesJobComponent) component).setAutowiredEnabled((boolean) value); return true;
             default: return false;
diff --git a/dsl/camel-componentdsl/src/generated/resources/metadata.json b/dsl/camel-componentdsl/src/generated/resources/metadata.json
index eca42dfaaf4..fa05780da7f 100644
--- a/dsl/camel-componentdsl/src/generated/resources/metadata.json
+++ b/dsl/camel-componentdsl/src/generated/resources/metadata.json
@@ -3016,7 +3016,7 @@
     "name": "hdfs",
     "title": "HDFS",
     "description": "Read and write from\/to an HDFS filesystem using Hadoop 2.x.",
-    "deprecated": false,
+    "deprecated": true,
     "firstVersion": "2.14.0",
     "label": "bigdata,file",
     "javaType": "org.apache.camel.component.hdfs.HdfsComponent",
@@ -4075,6 +4075,28 @@
     "producerOnly": false,
     "lenientProperties": false
   },
+  "KubernetesCronjobComponentBuilderFactory": {
+    "kind": "component",
+    "name": "kubernetes-cronjob",
+    "title": "Kubernetes Cronjob",
+    "description": "Perform operations on Kubernetes CronJob.",
+    "deprecated": false,
+    "firstVersion": "4.3.0",
+    "label": "container,cloud",
+    "javaType": "org.apache.camel.component.kubernetes.cronjob.KubernetesCronJobComponent",
+    "supportLevel": "Preview",
+    "groupId": "org.apache.camel",
+    "artifactId": "camel-kubernetes",
+    "version": "4.3.0-SNAPSHOT",
+    "scheme": "kubernetes-cronjob",
+    "extendsScheme": "",
+    "syntax": "kubernetes-cronjob:masterUrl",
+    "async": false,
+    "api": false,
+    "consumerOnly": false,
+    "producerOnly": true,
+    "lenientProperties": false
+  },
   "KubernetesCustomResourcesComponentBuilderFactory": {
     "kind": "component",
     "name": "kubernetes-custom-resources",
@@ -4182,7 +4204,7 @@
     "async": false,
     "api": false,
     "consumerOnly": false,
-    "producerOnly": false,
+    "producerOnly": true,
     "lenientProperties": false
   },
   "KubernetesNamespacesComponentBuilderFactory": {
diff --git a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/EndpointBuilderFactory.java b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/EndpointBuilderFactory.java
index 0b34c068cbe..83664133d54 100644
--- a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/EndpointBuilderFactory.java
+++ b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/EndpointBuilderFactory.java
@@ -192,6 +192,7 @@ public interface EndpointBuilderFactory
             org.apache.camel.builder.endpoint.dsl.KinesisFirehose2EndpointBuilderFactory.KinesisFirehose2Builders,
             org.apache.camel.builder.endpoint.dsl.KnativeEndpointBuilderFactory.KnativeBuilders,
             org.apache.camel.builder.endpoint.dsl.KubernetesConfigMapsEndpointBuilderFactory.KubernetesConfigMapsBuilders,
+            org.apache.camel.builder.endpoint.dsl.KubernetesCronJobEndpointBuilderFactory.KubernetesCronJobBuilders,
             org.apache.camel.builder.endpoint.dsl.KubernetesCustomResourcesEndpointBuilderFactory.KubernetesCustomResourcesBuilders,
             org.apache.camel.builder.endpoint.dsl.KubernetesDeploymentsEndpointBuilderFactory.KubernetesDeploymentsBuilders,
             org.apache.camel.builder.endpoint.dsl.KubernetesEventsEndpointBuilderFactory.KubernetesEventsBuilders,
diff --git a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/EndpointBuilders.java b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/EndpointBuilders.java
index fe8b0517b5a..497aa5f1a81 100644
--- a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/EndpointBuilders.java
+++ b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/EndpointBuilders.java
@@ -189,6 +189,7 @@ public interface EndpointBuilders
             org.apache.camel.builder.endpoint.dsl.KinesisFirehose2EndpointBuilderFactory,
             org.apache.camel.builder.endpoint.dsl.KnativeEndpointBuilderFactory,
             org.apache.camel.builder.endpoint.dsl.KubernetesConfigMapsEndpointBuilderFactory,
+            org.apache.camel.builder.endpoint.dsl.KubernetesCronJobEndpointBuilderFactory,
             org.apache.camel.builder.endpoint.dsl.KubernetesCustomResourcesEndpointBuilderFactory,
             org.apache.camel.builder.endpoint.dsl.KubernetesDeploymentsEndpointBuilderFactory,
             org.apache.camel.builder.endpoint.dsl.KubernetesEventsEndpointBuilderFactory,
diff --git a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/StaticEndpointBuilders.java b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/StaticEndpointBuilders.java
index 16e0a53cc5d..ac2197a8196 100644
--- a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/StaticEndpointBuilders.java
+++ b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/StaticEndpointBuilders.java
@@ -6461,6 +6461,7 @@ public class StaticEndpointBuilders {
      * @param path hostName:port/path
      * @return the dsl builder
      */
+    @Deprecated
     public static org.apache.camel.builder.endpoint.dsl.HdfsEndpointBuilderFactory.HdfsEndpointBuilder hdfs(
             String path) {
         return org.apache.camel.builder.endpoint.dsl.HdfsEndpointBuilderFactory.endpointBuilder("hdfs", path);
@@ -6490,6 +6491,7 @@ public class StaticEndpointBuilders {
      * @param path hostName:port/path
      * @return the dsl builder
      */
+    @Deprecated
     public static org.apache.camel.builder.endpoint.dsl.HdfsEndpointBuilderFactory.HdfsEndpointBuilder hdfs(
             String componentName,
             String path) {
@@ -8679,6 +8681,49 @@ public class StaticEndpointBuilders {
             String path) {
         return org.apache.camel.builder.endpoint.dsl.KubernetesConfigMapsEndpointBuilderFactory.endpointBuilder(componentName, path);
     }
+    /**
+     * Kubernetes Cronjob (camel-kubernetes)
+     * Perform operations on Kubernetes CronJob.
+     * 
+     * Category: container,cloud
+     * Since: 4.3
+     * Maven coordinates: org.apache.camel:camel-kubernetes
+     * 
+     * Syntax: <code>kubernetes-cronjob:masterUrl</code>
+     * 
+     * Path parameter: masterUrl (required)
+     * Kubernetes Master url
+     * 
+     * @param path masterUrl
+     * @return the dsl builder
+     */
+    public static org.apache.camel.builder.endpoint.dsl.KubernetesCronJobEndpointBuilderFactory.KubernetesCronJobEndpointBuilder kubernetesCronjob(
+            String path) {
+        return org.apache.camel.builder.endpoint.dsl.KubernetesCronJobEndpointBuilderFactory.endpointBuilder("kubernetes-cronjob", path);
+    }
+    /**
+     * Kubernetes Cronjob (camel-kubernetes)
+     * Perform operations on Kubernetes CronJob.
+     * 
+     * Category: container,cloud
+     * Since: 4.3
+     * Maven coordinates: org.apache.camel:camel-kubernetes
+     * 
+     * Syntax: <code>kubernetes-cronjob:masterUrl</code>
+     * 
+     * Path parameter: masterUrl (required)
+     * Kubernetes Master url
+     * 
+     * @param componentName to use a custom component name for the endpoint
+     * instead of the default name
+     * @param path masterUrl
+     * @return the dsl builder
+     */
+    public static org.apache.camel.builder.endpoint.dsl.KubernetesCronJobEndpointBuilderFactory.KubernetesCronJobEndpointBuilder kubernetesCronjob(
+            String componentName,
+            String path) {
+        return org.apache.camel.builder.endpoint.dsl.KubernetesCronJobEndpointBuilderFactory.endpointBuilder(componentName, path);
+    }
     /**
      * Kubernetes Custom Resources (camel-kubernetes)
      * Perform operations on Kubernetes Custom Resources and get notified on
diff --git a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/HdfsEndpointBuilderFactory.java b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/HdfsEndpointBuilderFactory.java
index f675f2269aa..c16ca548534 100644
--- a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/HdfsEndpointBuilderFactory.java
+++ b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/HdfsEndpointBuilderFactory.java
@@ -2662,6 +2662,7 @@ public interface HdfsEndpointBuilderFactory {
          * @param path hostName:port/path
          * @return the dsl builder
          */
+        @Deprecated
         default HdfsEndpointBuilder hdfs(String path) {
             return HdfsEndpointBuilderFactory.endpointBuilder("hdfs", path);
         }
@@ -2690,6 +2691,7 @@ public interface HdfsEndpointBuilderFactory {
          * @param path hostName:port/path
          * @return the dsl builder
          */
+        @Deprecated
         default HdfsEndpointBuilder hdfs(String componentName, String path) {
             return HdfsEndpointBuilderFactory.endpointBuilder(componentName, path);
         }
@@ -2786,6 +2788,7 @@ public interface HdfsEndpointBuilderFactory {
             return "CamelFileLength";
         }
     }
+    @Deprecated
     static HdfsEndpointBuilder endpointBuilder(String componentName, String path) {
         class HdfsEndpointBuilderImpl extends AbstractEndpointBuilder implements HdfsEndpointBuilder, AdvancedHdfsEndpointBuilder {
             public HdfsEndpointBuilderImpl(String path) {
diff --git a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/KubernetesCronJobEndpointBuilderFactory.java b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/KubernetesCronJobEndpointBuilderFactory.java
new file mode 100644
index 00000000000..22a3a2d403e
--- /dev/null
+++ b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/KubernetesCronJobEndpointBuilderFactory.java
@@ -0,0 +1,579 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+package org.apache.camel.builder.endpoint.dsl;
+
+import java.util.*;
+import java.util.concurrent.*;
+import java.util.function.*;
+import java.util.stream.*;
+import javax.annotation.processing.Generated;
+import org.apache.camel.builder.EndpointConsumerBuilder;
+import org.apache.camel.builder.EndpointProducerBuilder;
+import org.apache.camel.builder.endpoint.AbstractEndpointBuilder;
+
+/**
+ * Perform operations on Kubernetes CronJob.
+ * 
+ * Generated by camel build tools - do NOT edit this file!
+ */
+@Generated("org.apache.camel.maven.packaging.EndpointDslMojo")
+public interface KubernetesCronJobEndpointBuilderFactory {
+
+
+    /**
+     * Builder for endpoint for the Kubernetes Cronjob component.
+     */
+    public interface KubernetesCronJobEndpointBuilder
+            extends
+                EndpointProducerBuilder {
+        default AdvancedKubernetesCronJobEndpointBuilder advanced() {
+            return (AdvancedKubernetesCronJobEndpointBuilder) this;
+        }
+        /**
+         * The Kubernetes API Version to use.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: producer
+         * 
+         * @param apiVersion the value to set
+         * @return the dsl builder
+         */
+        default KubernetesCronJobEndpointBuilder apiVersion(String apiVersion) {
+            doSetProperty("apiVersion", apiVersion);
+            return this;
+        }
+        /**
+         * The dns domain, used for ServiceCall EIP.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: producer
+         * 
+         * @param dnsDomain the value to set
+         * @return the dsl builder
+         */
+        default KubernetesCronJobEndpointBuilder dnsDomain(String dnsDomain) {
+            doSetProperty("dnsDomain", dnsDomain);
+            return this;
+        }
+        /**
+         * Default KubernetesClient to use if provided.
+         * 
+         * The option is a:
+         * &lt;code&gt;io.fabric8.kubernetes.client.KubernetesClient&lt;/code&gt; type.
+         * 
+         * Group: producer
+         * 
+         * @param kubernetesClient the value to set
+         * @return the dsl builder
+         */
+        default KubernetesCronJobEndpointBuilder kubernetesClient(
+                io.fabric8.kubernetes.client.KubernetesClient kubernetesClient) {
+            doSetProperty("kubernetesClient", kubernetesClient);
+            return this;
+        }
+        /**
+         * Default KubernetesClient to use if provided.
+         * 
+         * The option will be converted to a
+         * &lt;code&gt;io.fabric8.kubernetes.client.KubernetesClient&lt;/code&gt; type.
+         * 
+         * Group: producer
+         * 
+         * @param kubernetesClient the value to set
+         * @return the dsl builder
+         */
+        default KubernetesCronJobEndpointBuilder kubernetesClient(
+                String kubernetesClient) {
+            doSetProperty("kubernetesClient", kubernetesClient);
+            return this;
+        }
+        /**
+         * The namespace.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: producer
+         * 
+         * @param namespace the value to set
+         * @return the dsl builder
+         */
+        default KubernetesCronJobEndpointBuilder namespace(String namespace) {
+            doSetProperty("namespace", namespace);
+            return this;
+        }
+        /**
+         * Producer operation to do on Kubernetes.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: producer
+         * 
+         * @param operation the value to set
+         * @return the dsl builder
+         */
+        default KubernetesCronJobEndpointBuilder operation(String operation) {
+            doSetProperty("operation", operation);
+            return this;
+        }
+        /**
+         * The port name, used for ServiceCall EIP.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: producer
+         * 
+         * @param portName the value to set
+         * @return the dsl builder
+         */
+        default KubernetesCronJobEndpointBuilder portName(String portName) {
+            doSetProperty("portName", portName);
+            return this;
+        }
+        /**
+         * The port protocol, used for ServiceCall EIP.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Default: tcp
+         * Group: producer
+         * 
+         * @param portProtocol the value to set
+         * @return the dsl builder
+         */
+        default KubernetesCronJobEndpointBuilder portProtocol(
+                String portProtocol) {
+            doSetProperty("portProtocol", portProtocol);
+            return this;
+        }
+        /**
+         * The CA Cert Data.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: security
+         * 
+         * @param caCertData the value to set
+         * @return the dsl builder
+         */
+        default KubernetesCronJobEndpointBuilder caCertData(String caCertData) {
+            doSetProperty("caCertData", caCertData);
+            return this;
+        }
+        /**
+         * The CA Cert File.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: security
+         * 
+         * @param caCertFile the value to set
+         * @return the dsl builder
+         */
+        default KubernetesCronJobEndpointBuilder caCertFile(String caCertFile) {
+            doSetProperty("caCertFile", caCertFile);
+            return this;
+        }
+        /**
+         * The Client Cert Data.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: security
+         * 
+         * @param clientCertData the value to set
+         * @return the dsl builder
+         */
+        default KubernetesCronJobEndpointBuilder clientCertData(
+                String clientCertData) {
+            doSetProperty("clientCertData", clientCertData);
+            return this;
+        }
+        /**
+         * The Client Cert File.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: security
+         * 
+         * @param clientCertFile the value to set
+         * @return the dsl builder
+         */
+        default KubernetesCronJobEndpointBuilder clientCertFile(
+                String clientCertFile) {
+            doSetProperty("clientCertFile", clientCertFile);
+            return this;
+        }
+        /**
+         * The Key Algorithm used by the client.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: security
+         * 
+         * @param clientKeyAlgo the value to set
+         * @return the dsl builder
+         */
+        default KubernetesCronJobEndpointBuilder clientKeyAlgo(
+                String clientKeyAlgo) {
+            doSetProperty("clientKeyAlgo", clientKeyAlgo);
+            return this;
+        }
+        /**
+         * The Client Key data.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: security
+         * 
+         * @param clientKeyData the value to set
+         * @return the dsl builder
+         */
+        default KubernetesCronJobEndpointBuilder clientKeyData(
+                String clientKeyData) {
+            doSetProperty("clientKeyData", clientKeyData);
+            return this;
+        }
+        /**
+         * The Client Key file.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: security
+         * 
+         * @param clientKeyFile the value to set
+         * @return the dsl builder
+         */
+        default KubernetesCronJobEndpointBuilder clientKeyFile(
+                String clientKeyFile) {
+            doSetProperty("clientKeyFile", clientKeyFile);
+            return this;
+        }
+        /**
+         * The Client Key Passphrase.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: security
+         * 
+         * @param clientKeyPassphrase the value to set
+         * @return the dsl builder
+         */
+        default KubernetesCronJobEndpointBuilder clientKeyPassphrase(
+                String clientKeyPassphrase) {
+            doSetProperty("clientKeyPassphrase", clientKeyPassphrase);
+            return this;
+        }
+        /**
+         * The Auth Token.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: security
+         * 
+         * @param oauthToken the value to set
+         * @return the dsl builder
+         */
+        default KubernetesCronJobEndpointBuilder oauthToken(String oauthToken) {
+            doSetProperty("oauthToken", oauthToken);
+            return this;
+        }
+        /**
+         * Password to connect to Kubernetes.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: security
+         * 
+         * @param password the value to set
+         * @return the dsl builder
+         */
+        default KubernetesCronJobEndpointBuilder password(String password) {
+            doSetProperty("password", password);
+            return this;
+        }
+        /**
+         * Define if the certs we used are trusted anyway or not.
+         * 
+         * The option is a: &lt;code&gt;java.lang.Boolean&lt;/code&gt; type.
+         * 
+         * Group: security
+         * 
+         * @param trustCerts the value to set
+         * @return the dsl builder
+         */
+        default KubernetesCronJobEndpointBuilder trustCerts(Boolean trustCerts) {
+            doSetProperty("trustCerts", trustCerts);
+            return this;
+        }
+        /**
+         * Define if the certs we used are trusted anyway or not.
+         * 
+         * The option will be converted to a
+         * &lt;code&gt;java.lang.Boolean&lt;/code&gt; type.
+         * 
+         * Group: security
+         * 
+         * @param trustCerts the value to set
+         * @return the dsl builder
+         */
+        default KubernetesCronJobEndpointBuilder trustCerts(String trustCerts) {
+            doSetProperty("trustCerts", trustCerts);
+            return this;
+        }
+        /**
+         * Username to connect to Kubernetes.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: security
+         * 
+         * @param username the value to set
+         * @return the dsl builder
+         */
+        default KubernetesCronJobEndpointBuilder username(String username) {
+            doSetProperty("username", username);
+            return this;
+        }
+    }
+
+    /**
+     * Advanced builder for endpoint for the Kubernetes Cronjob component.
+     */
+    public interface AdvancedKubernetesCronJobEndpointBuilder
+            extends
+                EndpointProducerBuilder {
+        default KubernetesCronJobEndpointBuilder basic() {
+            return (KubernetesCronJobEndpointBuilder) this;
+        }
+        /**
+         * Whether the producer should be started lazy (on the first message).
+         * By starting lazy you can use this to allow CamelContext and routes to
+         * startup in situations where a producer may otherwise fail during
+         * starting and cause the route to fail being started. By deferring this
+         * startup to be lazy then the startup failure can be handled during
+         * routing messages via Camel's routing error handlers. Beware that when
+         * the first message is processed then creating and starting the
+         * producer may take a little time and prolong the total processing time
+         * of the processing.
+         * 
+         * The option is a: &lt;code&gt;boolean&lt;/code&gt; type.
+         * 
+         * Default: false
+         * Group: producer (advanced)
+         * 
+         * @param lazyStartProducer the value to set
+         * @return the dsl builder
+         */
+        default AdvancedKubernetesCronJobEndpointBuilder lazyStartProducer(
+                boolean lazyStartProducer) {
+            doSetProperty("lazyStartProducer", lazyStartProducer);
+            return this;
+        }
+        /**
+         * Whether the producer should be started lazy (on the first message).
+         * By starting lazy you can use this to allow CamelContext and routes to
+         * startup in situations where a producer may otherwise fail during
+         * starting and cause the route to fail being started. By deferring this
+         * startup to be lazy then the startup failure can be handled during
+         * routing messages via Camel's routing error handlers. Beware that when
+         * the first message is processed then creating and starting the
+         * producer may take a little time and prolong the total processing time
+         * of the processing.
+         * 
+         * The option will be converted to a &lt;code&gt;boolean&lt;/code&gt;
+         * type.
+         * 
+         * Default: false
+         * Group: producer (advanced)
+         * 
+         * @param lazyStartProducer the value to set
+         * @return the dsl builder
+         */
+        default AdvancedKubernetesCronJobEndpointBuilder lazyStartProducer(
+                String lazyStartProducer) {
+            doSetProperty("lazyStartProducer", lazyStartProducer);
+            return this;
+        }
+        /**
+         * Connection timeout in milliseconds to use when making requests to the
+         * Kubernetes API server.
+         * 
+         * The option is a: &lt;code&gt;java.lang.Integer&lt;/code&gt; type.
+         * 
+         * Group: advanced
+         * 
+         * @param connectionTimeout the value to set
+         * @return the dsl builder
+         */
+        default AdvancedKubernetesCronJobEndpointBuilder connectionTimeout(
+                Integer connectionTimeout) {
+            doSetProperty("connectionTimeout", connectionTimeout);
+            return this;
+        }
+        /**
+         * Connection timeout in milliseconds to use when making requests to the
+         * Kubernetes API server.
+         * 
+         * The option will be converted to a
+         * &lt;code&gt;java.lang.Integer&lt;/code&gt; type.
+         * 
+         * Group: advanced
+         * 
+         * @param connectionTimeout the value to set
+         * @return the dsl builder
+         */
+        default AdvancedKubernetesCronJobEndpointBuilder connectionTimeout(
+                String connectionTimeout) {
+            doSetProperty("connectionTimeout", connectionTimeout);
+            return this;
+        }
+    }
+
+    public interface KubernetesCronJobBuilders {
+        /**
+         * Kubernetes Cronjob (camel-kubernetes)
+         * Perform operations on Kubernetes CronJob.
+         * 
+         * Category: container,cloud
+         * Since: 4.3
+         * Maven coordinates: org.apache.camel:camel-kubernetes
+         * 
+         * @return the dsl builder for the headers' name.
+         */
+        default KubernetesCronJobHeaderNameBuilder kubernetesCronjob() {
+            return KubernetesCronJobHeaderNameBuilder.INSTANCE;
+        }
+        /**
+         * Kubernetes Cronjob (camel-kubernetes)
+         * Perform operations on Kubernetes CronJob.
+         * 
+         * Category: container,cloud
+         * Since: 4.3
+         * Maven coordinates: org.apache.camel:camel-kubernetes
+         * 
+         * Syntax: <code>kubernetes-cronjob:masterUrl</code>
+         * 
+         * Path parameter: masterUrl (required)
+         * Kubernetes Master url
+         * 
+         * @param path masterUrl
+         * @return the dsl builder
+         */
+        default KubernetesCronJobEndpointBuilder kubernetesCronjob(String path) {
+            return KubernetesCronJobEndpointBuilderFactory.endpointBuilder("kubernetes-cronjob", path);
+        }
+        /**
+         * Kubernetes Cronjob (camel-kubernetes)
+         * Perform operations on Kubernetes CronJob.
+         * 
+         * Category: container,cloud
+         * Since: 4.3
+         * Maven coordinates: org.apache.camel:camel-kubernetes
+         * 
+         * Syntax: <code>kubernetes-cronjob:masterUrl</code>
+         * 
+         * Path parameter: masterUrl (required)
+         * Kubernetes Master url
+         * 
+         * @param componentName to use a custom component name for the endpoint
+         * instead of the default name
+         * @param path masterUrl
+         * @return the dsl builder
+         */
+        default KubernetesCronJobEndpointBuilder kubernetesCronjob(
+                String componentName,
+                String path) {
+            return KubernetesCronJobEndpointBuilderFactory.endpointBuilder(componentName, path);
+        }
+    }
+
+    /**
+     * The builder of headers' name for the Kubernetes Cronjob component.
+     */
+    public static class KubernetesCronJobHeaderNameBuilder {
+        /**
+         * The internal instance of the builder used to access to all the
+         * methods representing the name of headers.
+         */
+        private static final KubernetesCronJobHeaderNameBuilder INSTANCE = new KubernetesCronJobHeaderNameBuilder();
+
+        /**
+         * The Producer operation.
+         * 
+         * The option is a: {@code String} type.
+         * 
+         * Group: producer
+         * 
+         * @return the name of the header {@code KubernetesOperation}.
+         */
+        public String kubernetesOperation() {
+            return "CamelKubernetesOperation";
+        }
+
+        /**
+         * The Cronjob labels.
+         * 
+         * The option is a: {@code Map<String, String>} type.
+         * 
+         * Group: producer
+         * 
+         * @return the name of the header {@code KubernetesCronJobLabels}.
+         */
+        public String kubernetesCronJobLabels() {
+            return "CamelKubernetesCronJobLabels";
+        }
+
+        /**
+         * The Cronjob name.
+         * 
+         * The option is a: {@code String} type.
+         * 
+         * Group: producer
+         * 
+         * @return the name of the header {@code KubernetesCronJobName}.
+         */
+        public String kubernetesCronJobName() {
+            return "CamelKubernetesCronJobName";
+        }
+
+        /**
+         * The spec for a Job.
+         * 
+         * The option is a: {@code
+         * io.fabric8.kubernetes.api.model.batch.v1.CronJobSpec} type.
+         * 
+         * Group: producer
+         * 
+         * @return the name of the header {@code KubernetesCronJobSpec}.
+         */
+        public String kubernetesCronJobSpec() {
+            return "CamelKubernetesCronJobSpec";
+        }
+    }
+    static KubernetesCronJobEndpointBuilder endpointBuilder(
+            String componentName,
+            String path) {
+        class KubernetesCronJobEndpointBuilderImpl extends AbstractEndpointBuilder implements KubernetesCronJobEndpointBuilder, AdvancedKubernetesCronJobEndpointBuilder {
+            public KubernetesCronJobEndpointBuilderImpl(String path) {
+                super(componentName, path);
+            }
+        }
+        return new KubernetesCronJobEndpointBuilderImpl(path);
+    }
+}
\ No newline at end of file
diff --git a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/KubernetesJobEndpointBuilderFactory.java b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/KubernetesJobEndpointBuilderFactory.java
index 1252f1825a6..48032cd394a 100644
--- a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/KubernetesJobEndpointBuilderFactory.java
+++ b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/KubernetesJobEndpointBuilderFactory.java
@@ -34,1054 +34,12 @@ import org.apache.camel.builder.endpoint.AbstractEndpointBuilder;
 public interface KubernetesJobEndpointBuilderFactory {
 
 
-    /**
-     * Builder for endpoint consumers for the Kubernetes Job component.
-     */
-    public interface KubernetesJobEndpointConsumerBuilder
-            extends
-                EndpointConsumerBuilder {
-        default AdvancedKubernetesJobEndpointConsumerBuilder advanced() {
-            return (AdvancedKubernetesJobEndpointConsumerBuilder) this;
-        }
-        /**
-         * The Kubernetes API Version to use.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: common
-         * 
-         * @param apiVersion the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointConsumerBuilder apiVersion(
-                String apiVersion) {
-            doSetProperty("apiVersion", apiVersion);
-            return this;
-        }
-        /**
-         * The dns domain, used for ServiceCall EIP.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: common
-         * 
-         * @param dnsDomain the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointConsumerBuilder dnsDomain(String dnsDomain) {
-            doSetProperty("dnsDomain", dnsDomain);
-            return this;
-        }
-        /**
-         * Default KubernetesClient to use if provided.
-         * 
-         * The option is a:
-         * &lt;code&gt;io.fabric8.kubernetes.client.KubernetesClient&lt;/code&gt; type.
-         * 
-         * Group: common
-         * 
-         * @param kubernetesClient the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointConsumerBuilder kubernetesClient(
-                io.fabric8.kubernetes.client.KubernetesClient kubernetesClient) {
-            doSetProperty("kubernetesClient", kubernetesClient);
-            return this;
-        }
-        /**
-         * Default KubernetesClient to use if provided.
-         * 
-         * The option will be converted to a
-         * &lt;code&gt;io.fabric8.kubernetes.client.KubernetesClient&lt;/code&gt; type.
-         * 
-         * Group: common
-         * 
-         * @param kubernetesClient the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointConsumerBuilder kubernetesClient(
-                String kubernetesClient) {
-            doSetProperty("kubernetesClient", kubernetesClient);
-            return this;
-        }
-        /**
-         * The namespace.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: common
-         * 
-         * @param namespace the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointConsumerBuilder namespace(String namespace) {
-            doSetProperty("namespace", namespace);
-            return this;
-        }
-        /**
-         * The port name, used for ServiceCall EIP.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: common
-         * 
-         * @param portName the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointConsumerBuilder portName(String portName) {
-            doSetProperty("portName", portName);
-            return this;
-        }
-        /**
-         * The port protocol, used for ServiceCall EIP.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Default: tcp
-         * Group: common
-         * 
-         * @param portProtocol the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointConsumerBuilder portProtocol(
-                String portProtocol) {
-            doSetProperty("portProtocol", portProtocol);
-            return this;
-        }
-        /**
-         * The Consumer CRD Resource Group we would like to watch.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: consumer
-         * 
-         * @param crdGroup the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointConsumerBuilder crdGroup(String crdGroup) {
-            doSetProperty("crdGroup", crdGroup);
-            return this;
-        }
-        /**
-         * The Consumer CRD Resource name we would like to watch.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: consumer
-         * 
-         * @param crdName the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointConsumerBuilder crdName(String crdName) {
-            doSetProperty("crdName", crdName);
-            return this;
-        }
-        /**
-         * The Consumer CRD Resource Plural we would like to watch.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: consumer
-         * 
-         * @param crdPlural the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointConsumerBuilder crdPlural(String crdPlural) {
-            doSetProperty("crdPlural", crdPlural);
-            return this;
-        }
-        /**
-         * The Consumer CRD Resource Scope we would like to watch.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: consumer
-         * 
-         * @param crdScope the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointConsumerBuilder crdScope(String crdScope) {
-            doSetProperty("crdScope", crdScope);
-            return this;
-        }
-        /**
-         * The Consumer CRD Resource Version we would like to watch.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: consumer
-         * 
-         * @param crdVersion the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointConsumerBuilder crdVersion(
-                String crdVersion) {
-            doSetProperty("crdVersion", crdVersion);
-            return this;
-        }
-        /**
-         * The Consumer Label key when watching at some resources.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: consumer
-         * 
-         * @param labelKey the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointConsumerBuilder labelKey(String labelKey) {
-            doSetProperty("labelKey", labelKey);
-            return this;
-        }
-        /**
-         * The Consumer Label value when watching at some resources.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: consumer
-         * 
-         * @param labelValue the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointConsumerBuilder labelValue(
-                String labelValue) {
-            doSetProperty("labelValue", labelValue);
-            return this;
-        }
-        /**
-         * The Consumer pool size.
-         * 
-         * The option is a: &lt;code&gt;int&lt;/code&gt; type.
-         * 
-         * Default: 1
-         * Group: consumer
-         * 
-         * @param poolSize the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointConsumerBuilder poolSize(int poolSize) {
-            doSetProperty("poolSize", poolSize);
-            return this;
-        }
-        /**
-         * The Consumer pool size.
-         * 
-         * The option will be converted to a &lt;code&gt;int&lt;/code&gt; type.
-         * 
-         * Default: 1
-         * Group: consumer
-         * 
-         * @param poolSize the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointConsumerBuilder poolSize(String poolSize) {
-            doSetProperty("poolSize", poolSize);
-            return this;
-        }
-        /**
-         * The Consumer Resource Name we would like to watch.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: consumer
-         * 
-         * @param resourceName the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointConsumerBuilder resourceName(
-                String resourceName) {
-            doSetProperty("resourceName", resourceName);
-            return this;
-        }
-        /**
-         * The CA Cert Data.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: security
-         * 
-         * @param caCertData the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointConsumerBuilder caCertData(
-                String caCertData) {
-            doSetProperty("caCertData", caCertData);
-            return this;
-        }
-        /**
-         * The CA Cert File.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: security
-         * 
-         * @param caCertFile the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointConsumerBuilder caCertFile(
-                String caCertFile) {
-            doSetProperty("caCertFile", caCertFile);
-            return this;
-        }
-        /**
-         * The Client Cert Data.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: security
-         * 
-         * @param clientCertData the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointConsumerBuilder clientCertData(
-                String clientCertData) {
-            doSetProperty("clientCertData", clientCertData);
-            return this;
-        }
-        /**
-         * The Client Cert File.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: security
-         * 
-         * @param clientCertFile the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointConsumerBuilder clientCertFile(
-                String clientCertFile) {
-            doSetProperty("clientCertFile", clientCertFile);
-            return this;
-        }
-        /**
-         * The Key Algorithm used by the client.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: security
-         * 
-         * @param clientKeyAlgo the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointConsumerBuilder clientKeyAlgo(
-                String clientKeyAlgo) {
-            doSetProperty("clientKeyAlgo", clientKeyAlgo);
-            return this;
-        }
-        /**
-         * The Client Key data.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: security
-         * 
-         * @param clientKeyData the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointConsumerBuilder clientKeyData(
-                String clientKeyData) {
-            doSetProperty("clientKeyData", clientKeyData);
-            return this;
-        }
-        /**
-         * The Client Key file.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: security
-         * 
-         * @param clientKeyFile the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointConsumerBuilder clientKeyFile(
-                String clientKeyFile) {
-            doSetProperty("clientKeyFile", clientKeyFile);
-            return this;
-        }
-        /**
-         * The Client Key Passphrase.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: security
-         * 
-         * @param clientKeyPassphrase the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointConsumerBuilder clientKeyPassphrase(
-                String clientKeyPassphrase) {
-            doSetProperty("clientKeyPassphrase", clientKeyPassphrase);
-            return this;
-        }
-        /**
-         * The Auth Token.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: security
-         * 
-         * @param oauthToken the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointConsumerBuilder oauthToken(
-                String oauthToken) {
-            doSetProperty("oauthToken", oauthToken);
-            return this;
-        }
-        /**
-         * Password to connect to Kubernetes.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: security
-         * 
-         * @param password the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointConsumerBuilder password(String password) {
-            doSetProperty("password", password);
-            return this;
-        }
-        /**
-         * Define if the certs we used are trusted anyway or not.
-         * 
-         * The option is a: &lt;code&gt;java.lang.Boolean&lt;/code&gt; type.
-         * 
-         * Group: security
-         * 
-         * @param trustCerts the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointConsumerBuilder trustCerts(
-                Boolean trustCerts) {
-            doSetProperty("trustCerts", trustCerts);
-            return this;
-        }
-        /**
-         * Define if the certs we used are trusted anyway or not.
-         * 
-         * The option will be converted to a
-         * &lt;code&gt;java.lang.Boolean&lt;/code&gt; type.
-         * 
-         * Group: security
-         * 
-         * @param trustCerts the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointConsumerBuilder trustCerts(
-                String trustCerts) {
-            doSetProperty("trustCerts", trustCerts);
-            return this;
-        }
-        /**
-         * Username to connect to Kubernetes.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: security
-         * 
-         * @param username the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointConsumerBuilder username(String username) {
-            doSetProperty("username", username);
-            return this;
-        }
-    }
-
-    /**
-     * Advanced builder for endpoint consumers for the Kubernetes Job component.
-     */
-    public interface AdvancedKubernetesJobEndpointConsumerBuilder
-            extends
-                EndpointConsumerBuilder {
-        default KubernetesJobEndpointConsumerBuilder basic() {
-            return (KubernetesJobEndpointConsumerBuilder) this;
-        }
-        /**
-         * Allows for bridging the consumer to the Camel routing Error Handler,
-         * which mean any exceptions (if possible) occurred while the Camel
-         * consumer is trying to pickup incoming messages, or the likes, will
-         * now be processed as a message and handled by the routing Error
-         * Handler. Important: This is only possible if the 3rd party component
-         * allows Camel to be alerted if an exception was thrown. Some
-         * components handle this internally only, and therefore
-         * bridgeErrorHandler is not possible. In other situations we may
-         * improve the Camel component to hook into the 3rd party component and
-         * make this possible for future releases. By default the consumer will
-         * use the org.apache.camel.spi.ExceptionHandler to deal with
-         * exceptions, that will be logged at WARN or ERROR level and ignored.
-         * 
-         * The option is a: &lt;code&gt;boolean&lt;/code&gt; type.
-         * 
-         * Default: false
-         * Group: consumer (advanced)
-         * 
-         * @param bridgeErrorHandler the value to set
-         * @return the dsl builder
-         */
-        default AdvancedKubernetesJobEndpointConsumerBuilder bridgeErrorHandler(
-                boolean bridgeErrorHandler) {
-            doSetProperty("bridgeErrorHandler", bridgeErrorHandler);
-            return this;
-        }
-        /**
-         * Allows for bridging the consumer to the Camel routing Error Handler,
-         * which mean any exceptions (if possible) occurred while the Camel
-         * consumer is trying to pickup incoming messages, or the likes, will
-         * now be processed as a message and handled by the routing Error
-         * Handler. Important: This is only possible if the 3rd party component
-         * allows Camel to be alerted if an exception was thrown. Some
-         * components handle this internally only, and therefore
-         * bridgeErrorHandler is not possible. In other situations we may
-         * improve the Camel component to hook into the 3rd party component and
-         * make this possible for future releases. By default the consumer will
-         * use the org.apache.camel.spi.ExceptionHandler to deal with
-         * exceptions, that will be logged at WARN or ERROR level and ignored.
-         * 
-         * The option will be converted to a &lt;code&gt;boolean&lt;/code&gt;
-         * type.
-         * 
-         * Default: false
-         * Group: consumer (advanced)
-         * 
-         * @param bridgeErrorHandler the value to set
-         * @return the dsl builder
-         */
-        default AdvancedKubernetesJobEndpointConsumerBuilder bridgeErrorHandler(
-                String bridgeErrorHandler) {
-            doSetProperty("bridgeErrorHandler", bridgeErrorHandler);
-            return this;
-        }
-        /**
-         * To let the consumer use a custom ExceptionHandler. Notice if the
-         * option bridgeErrorHandler is enabled then this option is not in use.
-         * By default the consumer will deal with exceptions, that will be
-         * logged at WARN or ERROR level and ignored.
-         * 
-         * The option is a:
-         * &lt;code&gt;org.apache.camel.spi.ExceptionHandler&lt;/code&gt; type.
-         * 
-         * Group: consumer (advanced)
-         * 
-         * @param exceptionHandler the value to set
-         * @return the dsl builder
-         */
-        default AdvancedKubernetesJobEndpointConsumerBuilder exceptionHandler(
-                org.apache.camel.spi.ExceptionHandler exceptionHandler) {
-            doSetProperty("exceptionHandler", exceptionHandler);
-            return this;
-        }
-        /**
-         * To let the consumer use a custom ExceptionHandler. Notice if the
-         * option bridgeErrorHandler is enabled then this option is not in use.
-         * By default the consumer will deal with exceptions, that will be
-         * logged at WARN or ERROR level and ignored.
-         * 
-         * The option will be converted to a
-         * &lt;code&gt;org.apache.camel.spi.ExceptionHandler&lt;/code&gt; type.
-         * 
-         * Group: consumer (advanced)
-         * 
-         * @param exceptionHandler the value to set
-         * @return the dsl builder
-         */
-        default AdvancedKubernetesJobEndpointConsumerBuilder exceptionHandler(
-                String exceptionHandler) {
-            doSetProperty("exceptionHandler", exceptionHandler);
-            return this;
-        }
-        /**
-         * Sets the exchange pattern when the consumer creates an exchange.
-         * 
-         * The option is a:
-         * &lt;code&gt;org.apache.camel.ExchangePattern&lt;/code&gt; type.
-         * 
-         * Group: consumer (advanced)
-         * 
-         * @param exchangePattern the value to set
-         * @return the dsl builder
-         */
-        default AdvancedKubernetesJobEndpointConsumerBuilder exchangePattern(
-                org.apache.camel.ExchangePattern exchangePattern) {
-            doSetProperty("exchangePattern", exchangePattern);
-            return this;
-        }
-        /**
-         * Sets the exchange pattern when the consumer creates an exchange.
-         * 
-         * The option will be converted to a
-         * &lt;code&gt;org.apache.camel.ExchangePattern&lt;/code&gt; type.
-         * 
-         * Group: consumer (advanced)
-         * 
-         * @param exchangePattern the value to set
-         * @return the dsl builder
-         */
-        default AdvancedKubernetesJobEndpointConsumerBuilder exchangePattern(
-                String exchangePattern) {
-            doSetProperty("exchangePattern", exchangePattern);
-            return this;
-        }
-        /**
-         * Connection timeout in milliseconds to use when making requests to the
-         * Kubernetes API server.
-         * 
-         * The option is a: &lt;code&gt;java.lang.Integer&lt;/code&gt; type.
-         * 
-         * Group: advanced
-         * 
-         * @param connectionTimeout the value to set
-         * @return the dsl builder
-         */
-        default AdvancedKubernetesJobEndpointConsumerBuilder connectionTimeout(
-                Integer connectionTimeout) {
-            doSetProperty("connectionTimeout", connectionTimeout);
-            return this;
-        }
-        /**
-         * Connection timeout in milliseconds to use when making requests to the
-         * Kubernetes API server.
-         * 
-         * The option will be converted to a
-         * &lt;code&gt;java.lang.Integer&lt;/code&gt; type.
-         * 
-         * Group: advanced
-         * 
-         * @param connectionTimeout the value to set
-         * @return the dsl builder
-         */
-        default AdvancedKubernetesJobEndpointConsumerBuilder connectionTimeout(
-                String connectionTimeout) {
-            doSetProperty("connectionTimeout", connectionTimeout);
-            return this;
-        }
-    }
-
-    /**
-     * Builder for endpoint producers for the Kubernetes Job component.
-     */
-    public interface KubernetesJobEndpointProducerBuilder
-            extends
-                EndpointProducerBuilder {
-        default AdvancedKubernetesJobEndpointProducerBuilder advanced() {
-            return (AdvancedKubernetesJobEndpointProducerBuilder) this;
-        }
-        /**
-         * The Kubernetes API Version to use.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: common
-         * 
-         * @param apiVersion the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointProducerBuilder apiVersion(
-                String apiVersion) {
-            doSetProperty("apiVersion", apiVersion);
-            return this;
-        }
-        /**
-         * The dns domain, used for ServiceCall EIP.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: common
-         * 
-         * @param dnsDomain the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointProducerBuilder dnsDomain(String dnsDomain) {
-            doSetProperty("dnsDomain", dnsDomain);
-            return this;
-        }
-        /**
-         * Default KubernetesClient to use if provided.
-         * 
-         * The option is a:
-         * &lt;code&gt;io.fabric8.kubernetes.client.KubernetesClient&lt;/code&gt; type.
-         * 
-         * Group: common
-         * 
-         * @param kubernetesClient the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointProducerBuilder kubernetesClient(
-                io.fabric8.kubernetes.client.KubernetesClient kubernetesClient) {
-            doSetProperty("kubernetesClient", kubernetesClient);
-            return this;
-        }
-        /**
-         * Default KubernetesClient to use if provided.
-         * 
-         * The option will be converted to a
-         * &lt;code&gt;io.fabric8.kubernetes.client.KubernetesClient&lt;/code&gt; type.
-         * 
-         * Group: common
-         * 
-         * @param kubernetesClient the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointProducerBuilder kubernetesClient(
-                String kubernetesClient) {
-            doSetProperty("kubernetesClient", kubernetesClient);
-            return this;
-        }
-        /**
-         * The namespace.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: common
-         * 
-         * @param namespace the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointProducerBuilder namespace(String namespace) {
-            doSetProperty("namespace", namespace);
-            return this;
-        }
-        /**
-         * The port name, used for ServiceCall EIP.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: common
-         * 
-         * @param portName the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointProducerBuilder portName(String portName) {
-            doSetProperty("portName", portName);
-            return this;
-        }
-        /**
-         * The port protocol, used for ServiceCall EIP.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Default: tcp
-         * Group: common
-         * 
-         * @param portProtocol the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointProducerBuilder portProtocol(
-                String portProtocol) {
-            doSetProperty("portProtocol", portProtocol);
-            return this;
-        }
-        /**
-         * Producer operation to do on Kubernetes.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: producer
-         * 
-         * @param operation the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointProducerBuilder operation(String operation) {
-            doSetProperty("operation", operation);
-            return this;
-        }
-        /**
-         * The CA Cert Data.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: security
-         * 
-         * @param caCertData the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointProducerBuilder caCertData(
-                String caCertData) {
-            doSetProperty("caCertData", caCertData);
-            return this;
-        }
-        /**
-         * The CA Cert File.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: security
-         * 
-         * @param caCertFile the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointProducerBuilder caCertFile(
-                String caCertFile) {
-            doSetProperty("caCertFile", caCertFile);
-            return this;
-        }
-        /**
-         * The Client Cert Data.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: security
-         * 
-         * @param clientCertData the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointProducerBuilder clientCertData(
-                String clientCertData) {
-            doSetProperty("clientCertData", clientCertData);
-            return this;
-        }
-        /**
-         * The Client Cert File.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: security
-         * 
-         * @param clientCertFile the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointProducerBuilder clientCertFile(
-                String clientCertFile) {
-            doSetProperty("clientCertFile", clientCertFile);
-            return this;
-        }
-        /**
-         * The Key Algorithm used by the client.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: security
-         * 
-         * @param clientKeyAlgo the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointProducerBuilder clientKeyAlgo(
-                String clientKeyAlgo) {
-            doSetProperty("clientKeyAlgo", clientKeyAlgo);
-            return this;
-        }
-        /**
-         * The Client Key data.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: security
-         * 
-         * @param clientKeyData the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointProducerBuilder clientKeyData(
-                String clientKeyData) {
-            doSetProperty("clientKeyData", clientKeyData);
-            return this;
-        }
-        /**
-         * The Client Key file.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: security
-         * 
-         * @param clientKeyFile the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointProducerBuilder clientKeyFile(
-                String clientKeyFile) {
-            doSetProperty("clientKeyFile", clientKeyFile);
-            return this;
-        }
-        /**
-         * The Client Key Passphrase.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: security
-         * 
-         * @param clientKeyPassphrase the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointProducerBuilder clientKeyPassphrase(
-                String clientKeyPassphrase) {
-            doSetProperty("clientKeyPassphrase", clientKeyPassphrase);
-            return this;
-        }
-        /**
-         * The Auth Token.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: security
-         * 
-         * @param oauthToken the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointProducerBuilder oauthToken(
-                String oauthToken) {
-            doSetProperty("oauthToken", oauthToken);
-            return this;
-        }
-        /**
-         * Password to connect to Kubernetes.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: security
-         * 
-         * @param password the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointProducerBuilder password(String password) {
-            doSetProperty("password", password);
-            return this;
-        }
-        /**
-         * Define if the certs we used are trusted anyway or not.
-         * 
-         * The option is a: &lt;code&gt;java.lang.Boolean&lt;/code&gt; type.
-         * 
-         * Group: security
-         * 
-         * @param trustCerts the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointProducerBuilder trustCerts(
-                Boolean trustCerts) {
-            doSetProperty("trustCerts", trustCerts);
-            return this;
-        }
-        /**
-         * Define if the certs we used are trusted anyway or not.
-         * 
-         * The option will be converted to a
-         * &lt;code&gt;java.lang.Boolean&lt;/code&gt; type.
-         * 
-         * Group: security
-         * 
-         * @param trustCerts the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointProducerBuilder trustCerts(
-                String trustCerts) {
-            doSetProperty("trustCerts", trustCerts);
-            return this;
-        }
-        /**
-         * Username to connect to Kubernetes.
-         * 
-         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
-         * 
-         * Group: security
-         * 
-         * @param username the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobEndpointProducerBuilder username(String username) {
-            doSetProperty("username", username);
-            return this;
-        }
-    }
-
-    /**
-     * Advanced builder for endpoint producers for the Kubernetes Job component.
-     */
-    public interface AdvancedKubernetesJobEndpointProducerBuilder
-            extends
-                EndpointProducerBuilder {
-        default KubernetesJobEndpointProducerBuilder basic() {
-            return (KubernetesJobEndpointProducerBuilder) this;
-        }
-        /**
-         * Whether the producer should be started lazy (on the first message).
-         * By starting lazy you can use this to allow CamelContext and routes to
-         * startup in situations where a producer may otherwise fail during
-         * starting and cause the route to fail being started. By deferring this
-         * startup to be lazy then the startup failure can be handled during
-         * routing messages via Camel's routing error handlers. Beware that when
-         * the first message is processed then creating and starting the
-         * producer may take a little time and prolong the total processing time
-         * of the processing.
-         * 
-         * The option is a: &lt;code&gt;boolean&lt;/code&gt; type.
-         * 
-         * Default: false
-         * Group: producer (advanced)
-         * 
-         * @param lazyStartProducer the value to set
-         * @return the dsl builder
-         */
-        default AdvancedKubernetesJobEndpointProducerBuilder lazyStartProducer(
-                boolean lazyStartProducer) {
-            doSetProperty("lazyStartProducer", lazyStartProducer);
-            return this;
-        }
-        /**
-         * Whether the producer should be started lazy (on the first message).
-         * By starting lazy you can use this to allow CamelContext and routes to
-         * startup in situations where a producer may otherwise fail during
-         * starting and cause the route to fail being started. By deferring this
-         * startup to be lazy then the startup failure can be handled during
-         * routing messages via Camel's routing error handlers. Beware that when
-         * the first message is processed then creating and starting the
-         * producer may take a little time and prolong the total processing time
-         * of the processing.
-         * 
-         * The option will be converted to a &lt;code&gt;boolean&lt;/code&gt;
-         * type.
-         * 
-         * Default: false
-         * Group: producer (advanced)
-         * 
-         * @param lazyStartProducer the value to set
-         * @return the dsl builder
-         */
-        default AdvancedKubernetesJobEndpointProducerBuilder lazyStartProducer(
-                String lazyStartProducer) {
-            doSetProperty("lazyStartProducer", lazyStartProducer);
-            return this;
-        }
-        /**
-         * Connection timeout in milliseconds to use when making requests to the
-         * Kubernetes API server.
-         * 
-         * The option is a: &lt;code&gt;java.lang.Integer&lt;/code&gt; type.
-         * 
-         * Group: advanced
-         * 
-         * @param connectionTimeout the value to set
-         * @return the dsl builder
-         */
-        default AdvancedKubernetesJobEndpointProducerBuilder connectionTimeout(
-                Integer connectionTimeout) {
-            doSetProperty("connectionTimeout", connectionTimeout);
-            return this;
-        }
-        /**
-         * Connection timeout in milliseconds to use when making requests to the
-         * Kubernetes API server.
-         * 
-         * The option will be converted to a
-         * &lt;code&gt;java.lang.Integer&lt;/code&gt; type.
-         * 
-         * Group: advanced
-         * 
-         * @param connectionTimeout the value to set
-         * @return the dsl builder
-         */
-        default AdvancedKubernetesJobEndpointProducerBuilder connectionTimeout(
-                String connectionTimeout) {
-            doSetProperty("connectionTimeout", connectionTimeout);
-            return this;
-        }
-    }
-
     /**
      * Builder for endpoint for the Kubernetes Job component.
      */
     public interface KubernetesJobEndpointBuilder
             extends
-                KubernetesJobEndpointConsumerBuilder,
-                KubernetesJobEndpointProducerBuilder {
+                EndpointProducerBuilder {
         default AdvancedKubernetesJobEndpointBuilder advanced() {
             return (AdvancedKubernetesJobEndpointBuilder) this;
         }
@@ -1090,7 +48,7 @@ public interface KubernetesJobEndpointBuilderFactory {
          * 
          * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
          * 
-         * Group: common
+         * Group: producer
          * 
          * @param apiVersion the value to set
          * @return the dsl builder
@@ -1104,7 +62,7 @@ public interface KubernetesJobEndpointBuilderFactory {
          * 
          * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
          * 
-         * Group: common
+         * Group: producer
          * 
          * @param dnsDomain the value to set
          * @return the dsl builder
@@ -1119,7 +77,7 @@ public interface KubernetesJobEndpointBuilderFactory {
          * The option is a:
          * &lt;code&gt;io.fabric8.kubernetes.client.KubernetesClient&lt;/code&gt; type.
          * 
-         * Group: common
+         * Group: producer
          * 
          * @param kubernetesClient the value to set
          * @return the dsl builder
@@ -1135,7 +93,7 @@ public interface KubernetesJobEndpointBuilderFactory {
          * The option will be converted to a
          * &lt;code&gt;io.fabric8.kubernetes.client.KubernetesClient&lt;/code&gt; type.
          * 
-         * Group: common
+         * Group: producer
          * 
          * @param kubernetesClient the value to set
          * @return the dsl builder
@@ -1150,7 +108,7 @@ public interface KubernetesJobEndpointBuilderFactory {
          * 
          * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
          * 
-         * Group: common
+         * Group: producer
          * 
          * @param namespace the value to set
          * @return the dsl builder
@@ -1159,12 +117,26 @@ public interface KubernetesJobEndpointBuilderFactory {
             doSetProperty("namespace", namespace);
             return this;
         }
+        /**
+         * Producer operation to do on Kubernetes.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: producer
+         * 
+         * @param operation the value to set
+         * @return the dsl builder
+         */
+        default KubernetesJobEndpointBuilder operation(String operation) {
+            doSetProperty("operation", operation);
+            return this;
+        }
         /**
          * The port name, used for ServiceCall EIP.
          * 
          * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
          * 
-         * Group: common
+         * Group: producer
          * 
          * @param portName the value to set
          * @return the dsl builder
@@ -1179,7 +151,7 @@ public interface KubernetesJobEndpointBuilderFactory {
          * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
          * 
          * Default: tcp
-         * Group: common
+         * Group: producer
          * 
          * @param portProtocol the value to set
          * @return the dsl builder
@@ -1381,11 +353,59 @@ public interface KubernetesJobEndpointBuilderFactory {
      */
     public interface AdvancedKubernetesJobEndpointBuilder
             extends
-                AdvancedKubernetesJobEndpointConsumerBuilder,
-                AdvancedKubernetesJobEndpointProducerBuilder {
+                EndpointProducerBuilder {
         default KubernetesJobEndpointBuilder basic() {
             return (KubernetesJobEndpointBuilder) this;
         }
+        /**
+         * Whether the producer should be started lazy (on the first message).
+         * By starting lazy you can use this to allow CamelContext and routes to
+         * startup in situations where a producer may otherwise fail during
+         * starting and cause the route to fail being started. By deferring this
+         * startup to be lazy then the startup failure can be handled during
+         * routing messages via Camel's routing error handlers. Beware that when
+         * the first message is processed then creating and starting the
+         * producer may take a little time and prolong the total processing time
+         * of the processing.
+         * 
+         * The option is a: &lt;code&gt;boolean&lt;/code&gt; type.
+         * 
+         * Default: false
+         * Group: producer (advanced)
+         * 
+         * @param lazyStartProducer the value to set
+         * @return the dsl builder
+         */
+        default AdvancedKubernetesJobEndpointBuilder lazyStartProducer(
+                boolean lazyStartProducer) {
+            doSetProperty("lazyStartProducer", lazyStartProducer);
+            return this;
+        }
+        /**
+         * Whether the producer should be started lazy (on the first message).
+         * By starting lazy you can use this to allow CamelContext and routes to
+         * startup in situations where a producer may otherwise fail during
+         * starting and cause the route to fail being started. By deferring this
+         * startup to be lazy then the startup failure can be handled during
+         * routing messages via Camel's routing error handlers. Beware that when
+         * the first message is processed then creating and starting the
+         * producer may take a little time and prolong the total processing time
+         * of the processing.
+         * 
+         * The option will be converted to a &lt;code&gt;boolean&lt;/code&gt;
+         * type.
+         * 
+         * Default: false
+         * Group: producer (advanced)
+         * 
+         * @param lazyStartProducer the value to set
+         * @return the dsl builder
+         */
+        default AdvancedKubernetesJobEndpointBuilder lazyStartProducer(
+                String lazyStartProducer) {
+            doSetProperty("lazyStartProducer", lazyStartProducer);
+            return this;
+        }
         /**
          * Connection timeout in milliseconds to use when making requests to the
          * Kubernetes API server.
diff --git a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/LogEndpointBuilderFactory.java b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/LogEndpointBuilderFactory.java
index a39d2e0e1f8..57a0fefb6f2 100644
--- a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/LogEndpointBuilderFactory.java
+++ b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/LogEndpointBuilderFactory.java
@@ -777,6 +777,68 @@ public interface LogEndpointBuilderFactory {
             doSetProperty("showProperties", showProperties);
             return this;
         }
+        /**
+         * Show route Group.
+         * 
+         * The option is a: &lt;code&gt;boolean&lt;/code&gt; type.
+         * 
+         * Default: false
+         * Group: formatting
+         * 
+         * @param showRouteGroup the value to set
+         * @return the dsl builder
+         */
+        default LogEndpointBuilder showRouteGroup(boolean showRouteGroup) {
+            doSetProperty("showRouteGroup", showRouteGroup);
+            return this;
+        }
+        /**
+         * Show route Group.
+         * 
+         * The option will be converted to a &lt;code&gt;boolean&lt;/code&gt;
+         * type.
+         * 
+         * Default: false
+         * Group: formatting
+         * 
+         * @param showRouteGroup the value to set
+         * @return the dsl builder
+         */
+        default LogEndpointBuilder showRouteGroup(String showRouteGroup) {
+            doSetProperty("showRouteGroup", showRouteGroup);
+            return this;
+        }
+        /**
+         * Show route ID.
+         * 
+         * The option is a: &lt;code&gt;boolean&lt;/code&gt; type.
+         * 
+         * Default: false
+         * Group: formatting
+         * 
+         * @param showRouteId the value to set
+         * @return the dsl builder
+         */
+        default LogEndpointBuilder showRouteId(boolean showRouteId) {
+            doSetProperty("showRouteId", showRouteId);
+            return this;
+        }
+        /**
+         * Show route ID.
+         * 
+         * The option will be converted to a &lt;code&gt;boolean&lt;/code&gt;
+         * type.
+         * 
+         * Default: false
+         * Group: formatting
+         * 
+         * @param showRouteId the value to set
+         * @return the dsl builder
+         */
+        default LogEndpointBuilder showRouteId(String showRouteId) {
+            doSetProperty("showRouteId", showRouteId);
+            return this;
+        }
         /**
          * Show the stack trace, if an exchange has an exception. Only effective
          * if one of showAll, showException or showCaughtException are enabled.
diff --git a/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/KubernetesJobComponentBuilderFactory.java b/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/KubernetesCronjobComponentBuilderFactory.java
similarity index 58%
copy from dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/KubernetesJobComponentBuilderFactory.java
copy to dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/KubernetesCronjobComponentBuilderFactory.java
index d9841d873d9..ee6a1d459f8 100644
--- a/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/KubernetesJobComponentBuilderFactory.java
+++ b/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/KubernetesCronjobComponentBuilderFactory.java
@@ -20,79 +20,52 @@ import javax.annotation.processing.Generated;
 import org.apache.camel.Component;
 import org.apache.camel.builder.component.AbstractComponentBuilder;
 import org.apache.camel.builder.component.ComponentBuilder;
-import org.apache.camel.component.kubernetes.job.KubernetesJobComponent;
+import org.apache.camel.component.kubernetes.cronjob.KubernetesCronJobComponent;
 
 /**
  * Perform operations on Kubernetes Jobs.
  * 
  * Generated by camel-package-maven-plugin - do not edit this file!
  */
 @Generated("org.apache.camel.maven.packaging.ComponentDslMojo")
-public interface KubernetesJobComponentBuilderFactory {
+public interface KubernetesCronjobComponentBuilderFactory {
 
     /**
      * Kubernetes Job (camel-kubernetes)
      * Perform operations on Kubernetes Jobs.
      * 
      * Category: container,cloud
-     * Since: 2.23
+     * Since: 4.3
      * Maven coordinates: org.apache.camel:camel-kubernetes
      * 
      * @return the dsl builder
      */
-    static KubernetesJobComponentBuilder kubernetesJob() {
-        return new KubernetesJobComponentBuilderImpl();
+    static KubernetesCronjobComponentBuilder kubernetesCronjob() {
+        return new KubernetesCronjobComponentBuilderImpl();
     }
 
     /**
      * Builder for the Kubernetes Job component.
      */
-    interface KubernetesJobComponentBuilder
+    interface KubernetesCronjobComponentBuilder
             extends
-                ComponentBuilder<KubernetesJobComponent> {
+                ComponentBuilder<KubernetesCronJobComponent> {
         /**
          * To use an existing kubernetes client.
          * 
          * The option is a:
          * &lt;code&gt;io.fabric8.kubernetes.client.KubernetesClient&lt;/code&gt; type.
          * 
-         * Group: common
+         * Group: producer
          * 
          * @param kubernetesClient the value to set
          * @return the dsl builder
          */
-        default KubernetesJobComponentBuilder kubernetesClient(
+        default KubernetesCronjobComponentBuilder kubernetesClient(
                 io.fabric8.kubernetes.client.KubernetesClient kubernetesClient) {
             doSetProperty("kubernetesClient", kubernetesClient);
             return this;
         }
-        /**
-         * Allows for bridging the consumer to the Camel routing Error Handler,
-         * which mean any exceptions (if possible) occurred while the Camel
-         * consumer is trying to pickup incoming messages, or the likes, will
-         * now be processed as a message and handled by the routing Error
-         * Handler. Important: This is only possible if the 3rd party component
-         * allows Camel to be alerted if an exception was thrown. Some
-         * components handle this internally only, and therefore
-         * bridgeErrorHandler is not possible. In other situations we may
-         * improve the Camel component to hook into the 3rd party component and
-         * make this possible for future releases. By default the consumer will
-         * use the org.apache.camel.spi.ExceptionHandler to deal with
-         * exceptions, that will be logged at WARN or ERROR level and ignored.
-         * 
-         * The option is a: &lt;code&gt;boolean&lt;/code&gt; type.
-         * 
-         * Default: false
-         * Group: consumer
-         * 
-         * @param bridgeErrorHandler the value to set
-         * @return the dsl builder
-         */
-        default KubernetesJobComponentBuilder bridgeErrorHandler(
-                boolean bridgeErrorHandler) {
-            doSetProperty("bridgeErrorHandler", bridgeErrorHandler);
-            return this;
-        }
         /**
          * Whether the producer should be started lazy (on the first message).
          * By starting lazy you can use this to allow CamelContext and routes to
@@ -112,7 +85,7 @@ public interface KubernetesJobComponentBuilderFactory {
          * @param lazyStartProducer the value to set
          * @return the dsl builder
          */
-        default KubernetesJobComponentBuilder lazyStartProducer(
+        default KubernetesCronjobComponentBuilder lazyStartProducer(
                 boolean lazyStartProducer) {
             doSetProperty("lazyStartProducer", lazyStartProducer);
             return this;
@@ -133,21 +106,21 @@ public interface KubernetesJobComponentBuilderFactory {
          * @param autowiredEnabled the value to set
          * @return the dsl builder
          */
-        default KubernetesJobComponentBuilder autowiredEnabled(
+        default KubernetesCronjobComponentBuilder autowiredEnabled(
                 boolean autowiredEnabled) {
             doSetProperty("autowiredEnabled", autowiredEnabled);
             return this;
         }
     }
 
-    class KubernetesJobComponentBuilderImpl
+    class KubernetesCronjobComponentBuilderImpl
             extends
-                AbstractComponentBuilder<KubernetesJobComponent>
+                AbstractComponentBuilder<KubernetesCronJobComponent>
             implements
-                KubernetesJobComponentBuilder {
+                KubernetesCronjobComponentBuilder {
         @Override
-        protected KubernetesJobComponent buildConcreteComponent() {
-            return new KubernetesJobComponent();
+        protected KubernetesCronJobComponent buildConcreteComponent() {
+            return new KubernetesCronJobComponent();
         }
         @Override
         protected boolean setPropertyOnComponent(
@@ -155,10 +128,9 @@ public interface KubernetesJobComponentBuilderFactory {
                 String name,
                 Object value) {
             switch (name) {
-            case "kubernetesClient": ((KubernetesJobComponent) component).setKubernetesClient((io.fabric8.kubernetes.client.KubernetesClient) value); return true;
-            case "bridgeErrorHandler": ((KubernetesJobComponent) component).setBridgeErrorHandler((boolean) value); return true;
-            case "lazyStartProducer": ((KubernetesJobComponent) component).setLazyStartProducer((boolean) value); return true;
-            case "autowiredEnabled": ((KubernetesJobComponent) component).setAutowiredEnabled((boolean) value); return true;
+            case "kubernetesClient": ((KubernetesCronJobComponent) component).setKubernetesClient((io.fabric8.kubernetes.client.KubernetesClient) value); return true;
+            case "lazyStartProducer": ((KubernetesCronJobComponent) component).setLazyStartProducer((boolean) value); return true;
+            case "autowiredEnabled": ((KubernetesCronJobComponent) component).setAutowiredEnabled((boolean) value); return true;
             default: return false;
             }
         }
@@ -20,79 +20,52 @@ import javax.annotation.processing.Generated;
 
 /**
- * Perform operations on Kubernetes Jobs.
+ * Perform operations on Kubernetes CronJob.
  * 
  * Generated by camel-package-maven-plugin - do not edit this file!
@@ -20,79 +20,52 @@ import javax.annotation.processing.Generated;
 
     /**
-     * Kubernetes Job (camel-kubernetes)
-     * Perform operations on Kubernetes Jobs.
+     * Kubernetes Cronjob (camel-kubernetes)
+     * Perform operations on Kubernetes CronJob.
      * 
      * Category: container,cloud
@@ -20,79 +20,52 @@ import javax.annotation.processing.Generated;
 
     /**
-     * Builder for the Kubernetes Job component.
+     * Builder for the Kubernetes Cronjob component.
      */